package sun.net.www.protocol.http;

import java.util.ListIterator;
import java.util.LinkedList;
import java.util.HashMap;

public class AuthCacheImpl implements AuthCache
{
    HashMap<String, LinkedList<AuthCacheValue>> hashtable;
    
    public AuthCacheImpl() {
        this.hashtable = new HashMap();
    }
    
    public void setMap(HashMap<String, LinkedList<AuthCacheValue>> hashtable) {
        this.hashtable = hashtable;
    }
    
    @Override
    public synchronized void put(String s, AuthCacheValue authCacheValue) {
        LinkedList<Object> value = (LinkedList)this.hashtable.get(s);
        String path = authCacheValue.getPath();
        if (value == null) {
            value = new LinkedList();
            this.hashtable.put(s, value);
        }
        ListIterator<AuthCacheValue> listIterator = value.listIterator();
        while (listIterator.hasNext()) {
            AuthenticationInfo authenticationInfo = (AuthenticationInfo)listIterator.next();
            if (authenticationInfo.path == null || authenticationInfo.path.startsWith(path)) {
                listIterator.remove();
            }
            else {
                continue;
            }
        }
        listIterator.add(authCacheValue);
    }
    
    @Override
    public synchronized AuthCacheValue get(String key, String s) {
        LinkedList<Object> list = (LinkedList)this.hashtable.get(key);
        if (list == null || list.size() == 0) {
            return null;
        }
        if (s == null) {
            return (AuthenticationInfo)list.get(0);
        }
        ListIterator<Object> listIterator = list.listIterator();
        while (listIterator.hasNext()) {
            AuthenticationInfo authenticationInfo = (AuthenticationInfo)listIterator.next();
            if (s.startsWith(authenticationInfo.path)) {
                return authenticationInfo;
            }
            continue;
        }
        return null;
    }
    
    @Override
    public synchronized void remove(String key, AuthCacheValue authCacheValue) {
        LinkedList<Object> list = (LinkedList)this.hashtable.get(key);
        if (list == null) {
            return;
        }
        if (authCacheValue == null) {
            list.clear();
            return;
        }
        ListIterator<Object> listIterator = list.listIterator();
        while (listIterator.hasNext()) {
            if (authCacheValue.equals((Object)listIterator.next())) {
                listIterator.remove();
            }
            else {
                continue;
            }
        }
        return;
    }
}
